/*
 * $Id$
 * $URL$
 * ----------------------------------------------------------------------------
 * This file is part of JSBML. Please visit <http://sbml.org/Software/JSBML>
 * for the latest version of JSBML and more information about SBML.
 *
 * Copyright (C) 2009-2011 jointly by the following organizations:
 * 1. The University of Tuebingen, Germany
 * 2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
 * 3. The California Institute of Technology, Pasadena, CA, USA
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation. A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as <http://sbml.org/Software/JSBML/License>.
 * ----------------------------------------------------------------------------
 */

package org.sbml.jsbml;

/**
 * Base class for all the SBML components with an id and a name (optional or
 * not).
 * 
 * @author Andreas Dr&auml;ger
 * @author marine
 * 
 * @opt attributes
 * @opt types
 * @opt visibility
 */
public interface NamedSBase extends SBase {

	/**
	 * 
	 * @return the id of the element if it is set, an empty string otherwise.
	 */
	public String getId();

	/**
	 * 
	 * @return the name of the element if it is set, an empty string otherwise.
	 */
	public String getName();

	/**
	 * 
	 * @return true if the id is not null.
	 */
	public boolean isSetId();

	/**
	 * 
	 * @return true if the name is not null.
	 */
	public boolean isSetName();

	/**
	 * sets the id value with 'id'
	 * 
	 * @param id
	 */
	public void setId(String id);

	/**
	 * sets the name value with 'name'. If level is 1, sets automatically the id
	 * to 'name'
	 * 
	 * @param name
	 */
	public void setName(String name);

	/**
	 * sets the id value to null.
	 */
	public void unsetId();

	/**
	 * sets the name value to null.
	 */
	public void unsetName();
}
