/*
 * $Id$
 * $URL$
 * ----------------------------------------------------------------------------
 * This file is part of JSBML. Please visit <http://sbml.org/Software/JSBML>
 * for the latest version of JSBML and more information about SBML.
 *
 * Copyright (C) 2009-2011 jointly by the following organizations:
 * 1. The University of Tuebingen, Germany
 * 2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
 * 3. The California Institute of Technology, Pasadena, CA, USA
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation. A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as <http://sbml.org/Software/JSBML/License>.
 * ----------------------------------------------------------------------------
 */

package org.sbml.jsbml.util;

import java.io.OutputStream;
import java.io.Writer;

import org.w3c.dom.Node;

/**
 * 
 * A writer for XML DOM nodes.
 * 
 * @author Marco Donizelli
 * @since 1.0
 * 
 * @opt attributes
 * @opt types
 * @opt visibility
 */
public interface NodeWriter {

	/**
	 * 
	 * Writes an XML DOM node to a byte stream.
	 * 
	 * @param node
	 *            The <code>org.w3c.dom.Node</code> instance representing the
	 *            XML DOM node to be written to <code>byteStream</code>.
	 * @param byteStream
	 *            The byte stream where <code>node</code> is to be written.
	 * @param indent
	 *            Flag to indicate whether the output should be indented or not.
	 * 
	 */
	public void write(Node node, OutputStream byteStream, boolean indent);

	/**
	 * 
	 * Writes an XML DOM node to a character stream.
	 * 
	 * @param node
	 *            The <code>org.w3c.dom.Node</code> instance representing the
	 *            XML DOM node to be written to <code>characterStream</code>.
	 * @param characterStream
	 *            The character stream where <code>node</code> is to be written.
	 * @param indent
	 *            Flag to indicate whether the output should be indented or not.
	 * 
	 */
	public void write(Node node, Writer characterStream, boolean indent);
}
